Model card: drop training time from the results note
#4
by Viani - opened
- ASSET_SHA256SUMS +1 -1
- README.md +1 -1
ASSET_SHA256SUMS
CHANGED
|
@@ -10,5 +10,5 @@ d2023cc6a5a33abd405c3a9f63b7fabc84df6c917798bd7080114bcbe9294d89 stats/libero_s
|
|
| 10 |
905ccc23cf99504e6f17f9fac2b5115896304be2d2dc0a9522f8886095c0548c videos/libero-object.mp4
|
| 11 |
b5393c1ae185b1d05ad79edde9b5dc7b10543694b5c6be0d44084362e962e51d videos/libero-goal.mp4
|
| 12 |
38e0b77c8ec5988f3357ad0e28b5456b42c95b5698e96961d5d0cb2f9433751a videos/libero-long.mp4
|
| 13 |
-
|
| 14 |
f8337593ad4c0174982bcd6219ba666128bf5b2bf587c338921b89e2dfd7d1ff replay.mp4
|
|
|
|
| 10 |
905ccc23cf99504e6f17f9fac2b5115896304be2d2dc0a9522f8886095c0548c videos/libero-object.mp4
|
| 11 |
b5393c1ae185b1d05ad79edde9b5dc7b10543694b5c6be0d44084362e962e51d videos/libero-goal.mp4
|
| 12 |
38e0b77c8ec5988f3357ad0e28b5456b42c95b5698e96961d5d0cb2f9433751a videos/libero-long.mp4
|
| 13 |
+
41a834da72a00735a1e5acba20ec25388c97298acec6373c2e99086e8a53d64f README.md
|
| 14 |
f8337593ad4c0174982bcd6219ba666128bf5b2bf587c338921b89e2dfd7d1ff replay.mp4
|
README.md
CHANGED
|
@@ -35,7 +35,7 @@ LIBERO (all four suites, 50 episodes per task) on one AMD Instinct™ MI355X GPU
|
|
| 35 |
| CAE-FastWAM + GEAK (10 steps) | 97.28 ± 0.20 | 12.82 |
|
| 36 |
| CAE-FastWAM + GEAK (4 steps) | 97.33 ± 0.26 | 8.83 |
|
| 37 |
|
| 38 |
-
Success rate is the mean ± standard deviation over 11 full LIBERO runs (5 for the 4-step row). The FastWAM rows use the authors' [`yuanty/fastwam`](https://huggingface.co/yuanty/fastwam) checkpoint. For reference, `torch.compile` alone cuts latency 1.6–2.6× relative to eager PyTorch on MI355X, and GEAK runs 3.7× faster than `torch.compile` for FastWAM. Reproduce the table with `scripts/reproduce_cae_fastwam.sh` in the code repository.
|
| 39 |
|
| 40 |
## Files
|
| 41 |
|
|
|
|
| 35 |
| CAE-FastWAM + GEAK (10 steps) | 97.28 ± 0.20 | 12.82 |
|
| 36 |
| CAE-FastWAM + GEAK (4 steps) | 97.33 ± 0.26 | 8.83 |
|
| 37 |
|
| 38 |
+
Success rate is the mean ± standard deviation over 11 full LIBERO runs (5 for the 4-step row). The FastWAM rows use the authors' [`yuanty/fastwam`](https://huggingface.co/yuanty/fastwam) checkpoint. For reference, `torch.compile` alone cuts latency 1.6–2.6× relative to eager PyTorch on MI355X, and GEAK runs 3.7× faster than `torch.compile` for FastWAM. Reproduce the table with `scripts/reproduce_cae_fastwam.sh` in the code repository. Results are simulator measurements and may vary with configuration and software versions.
|
| 39 |
|
| 40 |
## Files
|
| 41 |
|